@@ -17,11 +17,11 @@ class BaseNodePair:
 
 class NodeTriple:
     def SubName(self):
-        return self.Subj.str()
+        return self.Subj.Identifier
     def PredName(self):
-        return self.Pred.str()
+        return self.Pred.Identifier
     def ObjName(self):
-        return self.Obj.str()
+        return self.Obj.Identifier
     def __init__(self,S,P,O):
         self.Subj=S
         self.Pred=P
@@ -246,7 +246,9 @@ class NamedNodeSet:
         return False
 
     def First(self, setname):
-        if self.set.has_key(setname) and len(self.set[setname])>0:
+        if self.set.has_key(setname) and type(self.set[setname]) is BaseOntNode:
+            return self.set[setname].Identifier # not sure why we have one that is not in a list...
+        if self.set.has_key(setname) and type(self.set[setname]) is list and len(self.set[setname])>0:
             return self.set[setname][0].Identifier
         return ''
 
@@ -402,9 +404,9 @@ class FuncOnt:
         self.CreateNSMapReverseLookup()
 
         # Create the root nodes, one for OWL, one for RDF
-        self.othing = 'owl:thing'
+        self.othing = 'owl:Thing'
         self.othing_node = BaseOntNode(self.othing,None,None)
-        self.rresource = 'rdf:resource'
+        self.rresource = 'rdf:Resource'
         self.rresource_node = BaseOntNode(self.rresource,None,None)
         self.identList.update({self.othing:self.othing_node})
         self.identList.update({self.rresource:self.rresource_node})
@@ -420,7 +422,7 @@ class FuncOnt:
                        'owl:TransitiveProperty','owl:SameAs','owl:Includes']
 
         for c in conceptList:
-            c_lower = c.lower()
+            c_lower = c # c.lower()  change this to not be lower case
             c_nocolon = c_lower.replace(':','')
             c_fullyqualifiedname=self.FullyQualifiedName(c_lower)
             setattr(self,c_nocolon,c_lower)
@@ -434,6 +436,10 @@ class FuncOnt:
 
     def DecodeLiteral(self,value):
         removeLast = False
+        if value==None:
+            return None
+        if len(value)==0:
+            return value
         if value[-1]==']':
             removeLast = True
         startval = value.find(':')
@@ -451,7 +457,7 @@ class FuncOnt:
         return newNode
 
     def AddPredFunction(self,ID,f):
-        print 'Not implemented yet'
+        #print 'Not implemented yet'
         self.identList[ID].PrimaryCode=f
         return
     #def ClearPredFuncList(self):
@@ -1157,9 +1163,9 @@ class FuncOnt:
                             return 0
                     elif not forceFuncNoCall:
                         #couldn't find a match, so try to make a function call
-                        # print 'Function Calls Not Implemented Yet'
-                        bP.PrimaryCode(Sub, Pred, Obj, results, self)
-                        return 0
+                        bP=self.GetBON(Pred)
+                        if bP is not None and bP.PrimaryCode is not None:
+                            return bP.PrimaryCode(Sub, Pred, Obj, results, self)
                     return 0 #nothing to return
                 else:
                     #(S, ?P, O)
@@ -1209,8 +1215,9 @@ class FuncOnt:
                     newSubList=self.GetEquivalentAndSubClassInverseNodeList(subList)
                     results.append(newSubList)
                 elif not forceFuncCall:
-                    return bP.PrimaryCode(Sub, Pred, Obj, results, self)
-                    #print 'Not implemented yet'
+                    bP = self.GetBON(Pred)
+                    if bP is not None and bP.PrimaryCode is not None:
+                        return bP.PrimaryCode(Sub, Pred, Obj, results, self)
                 return 0
 
 
@@ -1251,7 +1258,7 @@ class FuncOnt:
             print 'No files found.'
         iOntology = internalOntology()
         if 'N3' in iOntology.keys():
-            print 'Found {0} triples in the internal ontology set.'.format(len(iOntology['N3']))
+            print 'Found {0} triples in the internal ontology set of {1}.'.format(len(iOntology['N3']),pkgname)
         return filelist,iOntology,_newcode
 
     def GetOntologyModuleFiles(self,mdlFolder,mdlName):
@@ -1273,7 +1280,7 @@ class FuncOnt:
             print 'No files found.'
         iOntology = internalOntology()
         if 'N3' in iOntology.keys():
-            print 'Found {0} triples in the internal ontology set.'.format(len(iOntology['N3']))
+            print 'Found {0} triples in the internal ontology set of {1}.'.format(len(iOntology['N3']),mdlName)
         return filelist,iOntology,_newcode
 
     def ReadOntologyPackageOrModule(self, pkgfolder, pkgname):
